@@ -37,13 +37,13 @@ public class WatchFileTask extends Thread {
 
     private static final FileSystem FILE_SYSTEM = FileSystems.getDefault();
 
-    private final WatchService watchService;
+    private final transient WatchService watchService;
 
-    private final List<FileChangeListener> fileChangeListeners = new ArrayList<>();
+    private final transient List<FileChangeListener> fileChangeListeners = new ArrayList<>();
 
-    private volatile boolean watch = true;
+    private transient volatile boolean watch = true;
 
-    private final String directoryPath;
+    private final transient String directoryPath;
 
     public WatchFileTask(String directoryPath) {
         this.directoryPath = directoryPath;
@@ -55,12 +55,11 @@ public class WatchFileTask extends Thread {
             throw new IllegalArgumentException("must be a file directory : " + directoryPath);
         }
 
-        try {
-            WatchService service = FILE_SYSTEM.newWatchService();
-            path.register(service, StandardWatchEventKinds.OVERFLOW, StandardWatchEventKinds.ENTRY_MODIFY,
+        try (WatchService watchService = FILE_SYSTEM.newWatchService()) {
+            this.watchService = watchService;
+            path.register(this.watchService, StandardWatchEventKinds.OVERFLOW, StandardWatchEventKinds.ENTRY_MODIFY,
                     StandardWatchEventKinds.ENTRY_CREATE, StandardWatchEventKinds.ENTRY_DELETE);
-            this.watchService = service;
-        } catch (Throwable ex) {
+        } catch (Exception ex) {
             throw new UnsupportedOperationException("WatchService registry fail", ex);
         }
     }
@@ -90,7 +89,9 @@ public class WatchFileTask extends Thread {
                 for (WatchEvent<?> event : events) {
                     WatchEvent.Kind<?> kind = event.kind();
                     if (kind.equals(StandardWatchEventKinds.OVERFLOW)) {
-                        LOGGER.warn("[WatchFileTask] file overflow: {}", event.context());
+                        if (LOGGER.isWarnEnabled()) {
+                            LOGGER.warn("[WatchFileTask] file overflow: {}", event.context());
+                        }
                         continue;
                     }
                     precessWatchEvent(event);
@@ -102,7 +103,7 @@ public class WatchFileTask extends Thread {
                         LOGGER.debug("[WatchFileTask] file watch is interrupted");
                     }
                 }
-            } catch (Throwable ex) {
+            } catch (Exception ex) {
                 LOGGER.error("[WatchFileTask] an exception occurred during file listening : ", ex);
             }
         }
@@ -119,7 +120,7 @@ public class WatchFileTask extends Thread {
                     fileChangeListener.onChanged(context);
                 }
             }
-        } catch (Throwable ex) {
+        } catch (Exception ex) {
             LOGGER.error("[WatchFileTask] file change event callback error : ", ex);
         }
     }
