@@ -28,6 +28,7 @@ import java.net.SocketException;
 import java.net.URL;
 import java.net.UnknownHostException;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Enumeration;
 import java.util.List;
 import java.util.regex.Matcher;
@@ -44,7 +45,7 @@ import inet.ipaddr.IPAddressString;
 
 public class IPUtils {
 
-    private static final Logger logger = LoggerFactory.getLogger(IPUtils.class);
+    private static final Logger LOG = LoggerFactory.getLogger(IPUtils.class);
 
     public static String getLocalAddress() {
         // if the progress works under docker environment
@@ -56,23 +57,18 @@ public class IPUtils {
 
         //priority of networkInterface when generating client ip
         String priority = System.getProperty("networkInterface.priority", "eth0<eth1<bond1");
-
-        ArrayList<String> preferList = new ArrayList<String>();
-        for (String eth : priority.split("<")) {
-            preferList.add(eth);
-        }
+        List<String> list = Arrays.asList(priority.split("<"));
+        ArrayList<String> preferList = new ArrayList<>(list);
         NetworkInterface preferNetworkInterface = null;
 
         try {
             Enumeration<NetworkInterface> enumeration1 = NetworkInterface.getNetworkInterfaces();
             while (enumeration1.hasMoreElements()) {
                 final NetworkInterface networkInterface = enumeration1.nextElement();
-                if (!preferList.contains(networkInterface.getName())) {
-                    continue;
-                } else if (preferNetworkInterface == null) {
+                if (preferNetworkInterface == null) {
                     preferNetworkInterface = networkInterface;
                 } else if (preferList.indexOf(networkInterface.getName()) //get the networkInterface that has higher priority
-                        > preferList.indexOf(preferNetworkInterface.getName())) {
+                    > preferList.indexOf(preferNetworkInterface.getName())) {
                     preferNetworkInterface = networkInterface;
                 }
             }
@@ -96,11 +92,9 @@ public class IPUtils {
             // prefer ipv4
             if (!ipv4Result.isEmpty()) {
                 for (String ip : ipv4Result) {
-                    if (ip.startsWith("127.0") || ip.startsWith("192.168") || !isValidIPV4Address(ip)) {
-                        continue;
+                    if (isValidIPV4Address(ip) && !ip.startsWith("127.0") && !ip.startsWith("192.168")) {
+                        return ip;
                     }
-
-                    return ip;
                 }
 
                 return ipv4Result.get(ipv4Result.size() - 1);
@@ -110,12 +104,9 @@ public class IPUtils {
             //If failed to find,fall back to localhost
             final InetAddress localHost = InetAddress.getLocalHost();
             return normalizeHostAddress(localHost);
-        } catch (SocketException e) {
-            logger.error(e.getMessage());
-        } catch (UnknownHostException e) {
-            logger.error(e.getMessage());
+        } catch (SocketException | UnknownHostException e) {
+            LOG.error("socket or unknown host exception:", e);
         }
-
         return null;
     }
 
@@ -123,14 +114,14 @@ public class IPUtils {
 
         // Regex for digit from 0 to 255.
         String zeroTo255
-                = "(\\d{1,2}|(0|1)\\"
-                + "d{2}|2[0-4]\\d|25[0-5])";
+            = "(\\d{1,2}|(0|1)\\"
+            + "d{2}|2[0-4]\\d|25[0-5])";
 
         String regex
-                = zeroTo255 + "\\."
-                + zeroTo255 + "\\."
-                + zeroTo255 + "\\."
-                + zeroTo255;
+            = zeroTo255 + "\\."
+            + zeroTo255 + "\\."
+            + zeroTo255 + "\\."
+            + zeroTo255;
 
         // Compile the ReGex
         Pattern p = Pattern.compile(regex);
@@ -146,7 +137,7 @@ public class IPUtils {
         return m.matches();
     }
 
-    private static void getIpResult(ArrayList<String> ipv4Result, ArrayList<String> ipv6Result,
+    private static void getIpResult(List<String> ipv4Result, List<String> ipv6Result,
                                     Enumeration<InetAddress> en) {
         while (en.hasMoreElements()) {
             final InetAddress address = en.nextElement();
@@ -214,7 +205,7 @@ public class IPUtils {
                 return new IPAddressString(new URL(url).getHost()).isValid();
             }
         } catch (Exception e) {
-            logger.warn("Invalid URL format url={}", url, e);
+            LOG.warn("Invalid URL format url={}", url, e);
             return false;
         }
         return true;
@@ -229,7 +220,7 @@ public class IPUtils {
             String host = new URL(url).getHost();
             return new HostName(host).getAddress();
         } catch (MalformedURLException e) {
-            logger.error("Invalid URL format url={}", url, e);
+            LOG.error("Invalid URL format url={}", url, e);
             return null;
         }
     }
