@@ -45,27 +45,28 @@ public class EventmeshSubscribeBroadcast implements ReceiveMsgHook<EventMeshMess
         final String eventMeshGrpcPort = properties.getProperty(ExampleConstants.EVENTMESH_GRPC_PORT);
 
         EventMeshGrpcClientConfig eventMeshClientConfig = EventMeshGrpcClientConfig.builder()
-            .serverAddr(eventMeshIp)
-            .serverPort(Integer.parseInt(eventMeshGrpcPort))
-            .consumerGroup(ExampleConstants.DEFAULT_EVENTMESH_TEST_CONSUMER_GROUP)
-            .env("env").idc("idc")
-            .sys("1234").build();
+                .serverAddr(eventMeshIp)
+                .serverPort(Integer.parseInt(eventMeshGrpcPort))
+                .consumerGroup(ExampleConstants.DEFAULT_EVENTMESH_TEST_CONSUMER_GROUP)
+                .env("env").idc("idc")
+                .sys("1234").build();
 
         SubscriptionItem subscriptionItem = new SubscriptionItem();
         subscriptionItem.setTopic(ExampleConstants.EVENTMESH_GRPC_BROADCAT_TEST_TOPIC);
         subscriptionItem.setMode(SubscriptionMode.BROADCASTING);
         subscriptionItem.setType(SubscriptionType.ASYNC);
 
-        EventMeshGrpcConsumer eventMeshGrpcConsumer = new EventMeshGrpcConsumer(eventMeshClientConfig);
+        try (EventMeshGrpcConsumer eventMeshGrpcConsumer = new EventMeshGrpcConsumer(eventMeshClientConfig)) {
 
-        eventMeshGrpcConsumer.init();
+            eventMeshGrpcConsumer.init();
 
-        eventMeshGrpcConsumer.registerListener(handler);
+            eventMeshGrpcConsumer.registerListener(handler);
 
-        eventMeshGrpcConsumer.subscribe(Collections.singletonList(subscriptionItem));
+            eventMeshGrpcConsumer.subscribe(Collections.singletonList(subscriptionItem));
 
-        Thread.sleep(60000);
-        eventMeshGrpcConsumer.unsubscribe(Collections.singletonList(subscriptionItem));
+            Thread.sleep(60000);
+            eventMeshGrpcConsumer.unsubscribe(Collections.singletonList(subscriptionItem));
+        }
     }
 
     @Override
