@@ -28,6 +28,10 @@ public class EventMeshRegisterInfo {
     private String endPoint;
     private Map<String, Map<String, Integer>> eventMeshInstanceNumMap;
 
+    private Map<String, String> metadata;
+
+    private String protocolType;
+
     public String getEventMeshClusterName() {
         return eventMeshClusterName;
     }
@@ -59,4 +63,20 @@ public class EventMeshRegisterInfo {
     public void setEventMeshInstanceNumMap(Map<String, Map<String, Integer>> eventMeshInstanceNumMap) {
         this.eventMeshInstanceNumMap = eventMeshInstanceNumMap;
     }
+
+    public Map<String, String> getMetadata() {
+        return metadata;
+    }
+
+    public void setMetadata(Map<String, String> metadata) {
+        this.metadata = metadata;
+    }
+
+    public String getProtocolType() {
+        return protocolType;
+    }
+
+    public void setProtocolType(String protocolType) {
+        this.protocolType = protocolType;
+    }
 }
