@@ -17,13 +17,14 @@
 
 package org.apache.eventmesh.runtime.admin.handler;
 
-import org.apache.eventmesh.admin.rocketmq.util.JsonUtils;
-import org.apache.eventmesh.admin.rocketmq.util.NetUtils;
 import org.apache.eventmesh.common.Constants;
+import org.apache.eventmesh.common.utils.JsonUtils;
+import org.apache.eventmesh.common.utils.NetUtils;
+import org.apache.eventmesh.runtime.admin.controller.HttpHandlerManager;
+import org.apache.eventmesh.runtime.common.EventHttpHandler;
 import org.apache.eventmesh.webhook.api.WebHookConfig;
 import org.apache.eventmesh.webhook.api.WebHookConfigOperation;
 
-
 import java.io.IOException;
 import java.io.OutputStream;
 
@@ -31,26 +32,27 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.sun.net.httpserver.HttpExchange;
-import com.sun.net.httpserver.HttpHandler;
 
 @SuppressWarnings("restriction")
-public class InsertWebHookConfigHandler implements HttpHandler {
+@EventHttpHandler(path = "/webhook/insertWebHookConfig")
+public class InsertWebHookConfigHandler extends AbstractHttpHandler {
 
     public Logger logger = LoggerFactory.getLogger(this.getClass());
 
-    private WebHookConfigOperation operation;
+    private final WebHookConfigOperation operation;
 
-    public InsertWebHookConfigHandler(WebHookConfigOperation operation) {
+    public InsertWebHookConfigHandler(WebHookConfigOperation operation, HttpHandlerManager httpHandlerManager) {
+        super(httpHandlerManager);
         this.operation = operation;
     }
 
     @Override
     public void handle(HttpExchange httpExchange) throws IOException {
-        httpExchange.sendResponseHeaders(200, 0);
+        NetUtils.sendSuccessResponseHeaders(httpExchange);
 
         // get requestBody and resolve to WebHookConfig
         String requestBody = NetUtils.parsePostBody(httpExchange);
-        WebHookConfig webHookConfig = JsonUtils.toObject(requestBody, WebHookConfig.class);
+        WebHookConfig webHookConfig = JsonUtils.deserialize(requestBody, WebHookConfig.class);
 
         try (OutputStream out = httpExchange.getResponseBody()) {
             Integer code = operation.insertWebHookConfig(webHookConfig); // operating result
