@@ -63,6 +63,10 @@ public class EventMeshGrpcServer {
 
     private final EventMeshGrpcConfiguration eventMeshGrpcConfiguration;
 
+    private static final int MIN_LIMIT = 5;
+
+    private static final int MAX_LIMIT = 10;
+
     private Server server;
 
     private ProducerManager producerManager;
@@ -132,7 +136,7 @@ public class EventMeshGrpcServer {
         grpcRetryer.start();
         server.start();
 
-        if (eventMeshGrpcConfiguration.eventMeshServerRegistryEnable) {
+        if (eventMeshGrpcConfiguration.isEventMeshServerRegistryEnable()) {
             this.register();
         }
 
@@ -152,7 +156,7 @@ public class EventMeshGrpcServer {
 
         server.shutdown();
 
-        if (eventMeshGrpcConfiguration.eventMeshServerRegistryEnable) {
+        if (eventMeshGrpcConfiguration.isEventMeshServerRegistryEnable()) {
             this.unRegister();
         }
 
@@ -166,8 +170,9 @@ public class EventMeshGrpcServer {
             String endPoints = IPUtils.getLocalAddress()
                 + EventMeshConstants.IP_PORT_SEPARATOR + eventMeshGrpcConfiguration.grpcServerPort;
             EventMeshRegisterInfo eventMeshRegisterInfo = new EventMeshRegisterInfo();
-            eventMeshRegisterInfo.setEventMeshClusterName(eventMeshGrpcConfiguration.eventMeshCluster);
-            eventMeshRegisterInfo.setEventMeshName(eventMeshGrpcConfiguration.eventMeshName + "-" + ConfigurationContextUtil.GRPC);
+            eventMeshRegisterInfo.setEventMeshClusterName(eventMeshGrpcConfiguration.getEventMeshCluster());
+            eventMeshRegisterInfo.setEventMeshName(eventMeshGrpcConfiguration.getEventMeshName() + "-"
+                    + ConfigurationContextUtil.GRPC);
             eventMeshRegisterInfo.setEndPoint(endPoints);
             eventMeshRegisterInfo.setProtocolType(ConfigurationContextUtil.GRPC);
             registerResult = registry.register(eventMeshRegisterInfo);
@@ -182,8 +187,8 @@ public class EventMeshGrpcServer {
         String endPoints = IPUtils.getLocalAddress()
             + EventMeshConstants.IP_PORT_SEPARATOR + eventMeshGrpcConfiguration.grpcServerPort;
         EventMeshUnRegisterInfo eventMeshUnRegisterInfo = new EventMeshUnRegisterInfo();
-        eventMeshUnRegisterInfo.setEventMeshClusterName(eventMeshGrpcConfiguration.eventMeshCluster);
-        eventMeshUnRegisterInfo.setEventMeshName(eventMeshGrpcConfiguration.eventMeshName);
+        eventMeshUnRegisterInfo.setEventMeshClusterName(eventMeshGrpcConfiguration.getEventMeshCluster());
+        eventMeshUnRegisterInfo.setEventMeshName(eventMeshGrpcConfiguration.getEventMeshName());
         eventMeshUnRegisterInfo.setEndPoint(endPoints);
         eventMeshUnRegisterInfo.setProtocolType(ConfigurationContextUtil.GRPC);
         boolean registerResult = registry.unRegister(eventMeshUnRegisterInfo);
@@ -262,7 +267,8 @@ public class EventMeshGrpcServer {
 
     private void initHttpClientPool() {
         httpClientPool = new LinkedList<>();
-        for (int i = 0; i < 8; i++) {
+        int clientPool = RandomUtils.nextInt(MIN_LIMIT, MAX_LIMIT);
+        for (int i = 0; i < clientPool; i++) {
             CloseableHttpClient client = HttpClients.createDefault();
             httpClientPool.add(client);
         }
@@ -270,7 +276,7 @@ public class EventMeshGrpcServer {
 
     private void initMetricsMonitor() throws Exception {
         final List<MetricsRegistry> metricsRegistries = Lists.newArrayList();
-        Optional.ofNullable(eventMeshGrpcConfiguration.eventMeshMetricsPluginType)
+        Optional.ofNullable(eventMeshGrpcConfiguration.getEventMeshMetricsPluginType())
             .ifPresent(
                 metricsPlugins -> metricsPlugins.forEach(
                     pluginType -> metricsRegistries.add(MetricsPluginFactory.getMetricsRegistry(pluginType))));
