@@ -21,6 +21,7 @@ import org.apache.eventmesh.common.config.CommonConfiguration;
 import org.apache.eventmesh.common.config.ConfigurationWrapper;
 import org.apache.eventmesh.common.utils.ConfigurationContextUtil;
 import org.apache.eventmesh.runtime.acl.Acl;
+import org.apache.eventmesh.runtime.admin.controller.ClientManageController;
 import org.apache.eventmesh.runtime.common.ServiceState;
 import org.apache.eventmesh.runtime.connector.ConnectorResource;
 import org.apache.eventmesh.runtime.constants.EventMeshConstants;
@@ -28,6 +29,7 @@ import org.apache.eventmesh.runtime.registry.Registry;
 import org.apache.eventmesh.runtime.trace.Trace;
 
 import java.util.List;
+import java.util.Objects;
 import java.util.concurrent.CopyOnWriteArrayList;
 
 import org.slf4j.Logger;
@@ -35,7 +37,7 @@ import org.slf4j.LoggerFactory;
 
 public class EventMeshServer {
 
-    public Logger logger = LoggerFactory.getLogger(this.getClass());
+    public static final Logger LOGGER = LoggerFactory.getLogger(EventMeshServer.class);
 
     private final Acl acl;
 
@@ -49,19 +51,23 @@ public class EventMeshServer {
 
     private final CommonConfiguration configuration;
 
+    private transient ClientManageController clientManageController;
+
     private static final List<EventMeshBootstrap> BOOTSTRAP_LIST = new CopyOnWriteArrayList<>();
 
-    public EventMeshServer(ConfigurationWrapper configurationWrapper) {
+    private static final String SERVER_STATE_MSG = "server state:{}";
+
+    public EventMeshServer(final ConfigurationWrapper configurationWrapper) throws Exception {
         CommonConfiguration configuration = new CommonConfiguration(configurationWrapper);
         configuration.init();
         this.configuration = configuration;
         this.acl = new Acl();
         this.registry = new Registry();
-        trace = new Trace(configuration.eventMeshServerTraceEnable);
+        trace = new Trace(configuration.isEventMeshServerTraceEnable());
         this.connectorResource = new ConnectorResource();
 
-        List<String> provideServerProtocols = configuration.eventMeshProvideServerProtocols;
-        for (String provideServerProtocol : provideServerProtocols) {
+        final List<String> provideServerProtocols = configuration.getEventMeshProvideServerProtocols();
+        for (final String provideServerProtocol : provideServerProtocols) {
             if (ConfigurationContextUtil.HTTP.equals(provideServerProtocol)) {
                 BOOTSTRAP_LIST.add(new EventMeshHttpBootstrap(this,
                         configurationWrapper, registry));
@@ -75,82 +81,125 @@ public class EventMeshServer {
                         registry));
             }
         }
+
+        init();
     }
 
-    public void init() throws Exception {
-        if (configuration != null && configuration.eventMeshServerSecurityEnable) {
-            acl.init(configuration.eventMeshSecurityPluginType);
-        }
-        // registry init
-        if (configuration != null && configuration.eventMeshServerRegistryEnable) {
-            registry.init(configuration.eventMeshRegistryPluginType);
+    private void init() throws Exception {
+        if (Objects.nonNull(configuration)) {
+            connectorResource.init(configuration.getEventMeshConnectorPluginType());
+            if (configuration.isEventMeshServerSecurityEnable()) {
+                acl.init(configuration.getEventMeshSecurityPluginType());
+            }
+            if (configuration.isEventMeshServerRegistryEnable()) {
+                registry.init(configuration.getEventMeshRegistryPluginType());
+            }
+            if (configuration.isEventMeshServerTraceEnable()) {
+                trace.init(configuration.getEventMeshTracePluginType());
+            }
         }
 
-        if (configuration != null && configuration.eventMeshServerTraceEnable) {
-            trace.init(configuration.eventMeshTracePluginType);
-        }
+        EventMeshTCPServer eventMeshTCPServer = null;
 
-        if (configuration != null) {
-            connectorResource.init(configuration.eventMeshConnectorPluginType);
-        }
+        EventMeshGrpcServer eventMeshGrpcServer = null;
+
+        EventMeshHTTPServer eventMeshHTTPServer = null;
 
         // server init
-        for (EventMeshBootstrap eventMeshBootstrap : BOOTSTRAP_LIST) {
+        for (final EventMeshBootstrap eventMeshBootstrap : BOOTSTRAP_LIST) {
             eventMeshBootstrap.init();
+            if (eventMeshBootstrap instanceof EventMeshTcpBootstrap) {
+                eventMeshTCPServer = ((EventMeshTcpBootstrap) eventMeshBootstrap).getEventMeshTcpServer();
+            }
+            if (eventMeshBootstrap instanceof EventMeshHttpBootstrap) {
+                eventMeshHTTPServer = ((EventMeshHttpBootstrap) eventMeshBootstrap).getEventMeshHttpServer();
+            }
+            if (eventMeshBootstrap instanceof EventMeshGrpcBootstrap) {
+                eventMeshGrpcServer = ((EventMeshGrpcBootstrap) eventMeshBootstrap).getEventMeshGrpcServer();
+            }
         }
 
-        String eventStore = System
-            .getProperty(EventMeshConstants.EVENT_STORE_PROPERTIES, System.getenv(EventMeshConstants.EVENT_STORE_ENV));
-        logger.info("eventStore : {}", eventStore);
+        if (Objects.nonNull(eventMeshTCPServer) && Objects.nonNull(eventMeshHTTPServer)
+            && Objects.nonNull(eventMeshGrpcServer)) {
+            clientManageController = new ClientManageController(eventMeshTCPServer,
+                eventMeshHTTPServer, eventMeshGrpcServer, registry);
+
+            clientManageController.setAdminWebHookConfigOperationManage(eventMeshTCPServer.getAdminWebHookConfigOperationManage());
+
+        }
+
+        final String eventStore = System
+                .getProperty(EventMeshConstants.EVENT_STORE_PROPERTIES, System.getenv(EventMeshConstants.EVENT_STORE_ENV));
+
+        if (LOGGER.isInfoEnabled()) {
+            LOGGER.info("eventStore : {}", eventStore);
+        }
 
         serviceState = ServiceState.INITED;
-        logger.info("server state:{}", serviceState);
+
+        if (LOGGER.isInfoEnabled()) {
+            LOGGER.info(SERVER_STATE_MSG, serviceState);
+        }
     }
 
     public void start() throws Exception {
-        if (configuration != null && configuration.eventMeshServerSecurityEnable) {
-            acl.start();
+        if (Objects.nonNull(configuration)) {
+            if (configuration.isEventMeshServerSecurityEnable()) {
+                acl.start();
+            }
+            // registry start
+            if (configuration.isEventMeshServerRegistryEnable()) {
+                registry.start();
+            }
         }
-        // registry start
-        if (configuration != null && configuration.eventMeshServerRegistryEnable) {
-            registry.start();
-        }
-
         // server start
-        for (EventMeshBootstrap eventMeshBootstrap : BOOTSTRAP_LIST) {
+        for (final EventMeshBootstrap eventMeshBootstrap : BOOTSTRAP_LIST) {
             eventMeshBootstrap.start();
         }
 
+        if (Objects.nonNull(clientManageController)) {
+            clientManageController.start();
+        }
+
+
         serviceState = ServiceState.RUNNING;
-        logger.info("server state:{}", serviceState);
+        if (LOGGER.isInfoEnabled()) {
+            LOGGER.info(SERVER_STATE_MSG, serviceState);
+        }
+
     }
 
     public void shutdown() throws Exception {
         serviceState = ServiceState.STOPING;
-        logger.info("server state:{}", serviceState);
+        if (LOGGER.isInfoEnabled()) {
+            LOGGER.info(SERVER_STATE_MSG, serviceState);
+        }
 
-        for (EventMeshBootstrap eventMeshBootstrap : BOOTSTRAP_LIST) {
+        for (final EventMeshBootstrap eventMeshBootstrap : BOOTSTRAP_LIST) {
             eventMeshBootstrap.shutdown();
         }
 
         if (configuration != null
-                && configuration.eventMeshServerRegistryEnable) {
+                && configuration.isEventMeshServerRegistryEnable()) {
             registry.shutdown();
         }
 
         connectorResource.release();
 
-        if (configuration != null && configuration.eventMeshServerSecurityEnable) {
+        if (configuration != null && configuration.isEventMeshServerSecurityEnable()) {
             acl.shutdown();
         }
 
-        if (configuration != null && configuration.eventMeshServerTraceEnable) {
+        if (configuration != null && configuration.isEventMeshServerTraceEnable()) {
             trace.shutdown();
         }
 
         ConfigurationContextUtil.clear();
         serviceState = ServiceState.STOPED;
-        logger.info("server state:{}", serviceState);
+
+        if (LOGGER.isInfoEnabled()) {
+            LOGGER.info(SERVER_STATE_MSG, serviceState);
+        }
     }
 
     public static Trace getTrace() {
@@ -165,7 +214,7 @@ public class EventMeshServer {
         return registry;
     }
 
-    public void setRegistry(Registry registry) {
+    public void setRegistry(final Registry registry) {
         this.registry = registry;
     }
 }
