@@ -20,6 +20,7 @@ package org.apache.eventmesh.runtime.core.consumergroup;
 import java.io.Serializable;
 import java.util.Map;
 import java.util.Objects;
+import java.util.concurrent.ConcurrentHashMap;
 
 import com.google.common.collect.Maps;
 
@@ -27,7 +28,8 @@ public class ConsumerGroupConf implements Serializable {
     //eg . 5013-1A0
     private String consumerGroup;
 
-    private Map<String, ConsumerGroupTopicConf> consumerGroupTopicConf = Maps.newConcurrentMap();
+    private final ConcurrentHashMap<String/*topic*/, ConsumerGroupTopicConf> consumerGroupTopicConf
+            = new ConcurrentHashMap<String, ConsumerGroupTopicConf>();
 
     public ConsumerGroupConf(String consumerGroup) {
         this.consumerGroup = consumerGroup;
@@ -45,10 +47,6 @@ public class ConsumerGroupConf implements Serializable {
         return consumerGroupTopicConf;
     }
 
-    public void setConsumerGroupTopicConf(Map<String, ConsumerGroupTopicConf> consumerGroupTopicConf) {
-        this.consumerGroupTopicConf = consumerGroupTopicConf;
-    }
-
     @Override
     public boolean equals(Object o) {
         if (this == o) {
