@@ -89,7 +89,8 @@ public class SendAsyncMessageProcessor {
         }
 
         String protocolType = requestHeader.getProtocolType();
-        ProtocolAdaptor<ProtocolTransportObject> grpcCommandProtocolAdaptor = ProtocolPluginFactory.getProtocolAdaptor(protocolType);
+        ProtocolAdaptor<ProtocolTransportObject> grpcCommandProtocolAdaptor =
+                ProtocolPluginFactory.getProtocolAdaptor(protocolType);
         CloudEvent cloudEvent = grpcCommandProtocolAdaptor.toCloudEvent(new SimpleMessageWrapper(message));
 
         String seqNum = message.getSeqNum();
@@ -100,7 +101,8 @@ public class SendAsyncMessageProcessor {
         ProducerManager producerManager = eventMeshGrpcServer.getProducerManager();
         EventMeshProducer eventMeshProducer = producerManager.getEventMeshProducer(producerGroup);
 
-        SendMessageContext sendMessageContext = new SendMessageContext(message.getSeqNum(), cloudEvent, eventMeshProducer, eventMeshGrpcServer);
+        SendMessageContext sendMessageContext = new SendMessageContext(message.getSeqNum(), cloudEvent,
+                eventMeshProducer, eventMeshGrpcServer);
 
         eventMeshGrpcServer.getMetricsMonitor().recordSendMsgToQueue();
         long startTime = System.currentTimeMillis();
@@ -127,7 +129,7 @@ public class SendAsyncMessageProcessor {
 
     private void doAclCheck(SimpleMessage message) throws AclException {
         RequestHeader requestHeader = message.getHeader();
-        if (eventMeshGrpcServer.getEventMeshGrpcConfiguration().eventMeshServerSecurityEnable) {
+        if (eventMeshGrpcServer.getEventMeshGrpcConfiguration().isEventMeshServerSecurityEnable()) {
             String remoteAdd = requestHeader.getIp();
             String user = requestHeader.getUsername();
             String pass = requestHeader.getPassword();
