@@ -23,14 +23,12 @@ import static org.apache.eventmesh.runtime.constants.EventMeshConstants.INSTANCE
 import static org.apache.eventmesh.runtime.constants.EventMeshConstants.IS_BROADCAST;
 
 import org.apache.eventmesh.api.AbstractContext;
-import org.apache.eventmesh.api.AsyncConsumeContext;
 import org.apache.eventmesh.api.EventListener;
 import org.apache.eventmesh.api.EventMeshAction;
 import org.apache.eventmesh.api.EventMeshAsyncConsumeContext;
 import org.apache.eventmesh.api.SendCallback;
 import org.apache.eventmesh.api.SendResult;
 import org.apache.eventmesh.api.exception.OnExceptionContext;
-import org.apache.eventmesh.common.Constants;
 import org.apache.eventmesh.common.protocol.SubscriptionItem;
 import org.apache.eventmesh.common.protocol.SubscriptionMode;
 import org.apache.eventmesh.common.protocol.http.common.ProtocolKey;
@@ -63,15 +61,15 @@ import io.opentelemetry.api.trace.Span;
 
 public class EventMeshConsumer {
 
-    private EventMeshHTTPServer eventMeshHTTPServer;
+    private final EventMeshHTTPServer eventMeshHTTPServer;
 
-    private AtomicBoolean started4Persistent = new AtomicBoolean(Boolean.FALSE);
+    private final AtomicBoolean started4Persistent = new AtomicBoolean(Boolean.FALSE);
 
-    private AtomicBoolean started4Broadcast = new AtomicBoolean(Boolean.FALSE);
+    private final AtomicBoolean started4Broadcast = new AtomicBoolean(Boolean.FALSE);
 
-    private AtomicBoolean inited4Persistent = new AtomicBoolean(Boolean.FALSE);
+    private final AtomicBoolean inited4Persistent = new AtomicBoolean(Boolean.FALSE);
 
-    private AtomicBoolean inited4Broadcast = new AtomicBoolean(Boolean.FALSE);
+    private final AtomicBoolean inited4Broadcast = new AtomicBoolean(Boolean.FALSE);
 
     public Logger logger = LoggerFactory.getLogger(this.getClass());
 
@@ -79,15 +77,17 @@ public class EventMeshConsumer {
 
     private ConsumerGroupConf consumerGroupConf;
 
-    private MQConsumerWrapper persistentMqConsumer;
+    private final MQConsumerWrapper persistentMqConsumer;
 
-    private MQConsumerWrapper broadcastMqConsumer;
+    private final MQConsumerWrapper broadcastMqConsumer;
 
     public EventMeshConsumer(EventMeshHTTPServer eventMeshHTTPServer, ConsumerGroupConf consumerGroupConf) {
         this.eventMeshHTTPServer = eventMeshHTTPServer;
         this.consumerGroupConf = consumerGroupConf;
-        this.persistentMqConsumer = new MQConsumerWrapper(eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshConnectorPluginType);
-        this.broadcastMqConsumer = new MQConsumerWrapper(eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshConnectorPluginType);
+        this.persistentMqConsumer = new MQConsumerWrapper(
+                eventMeshHTTPServer.getEventMeshHttpConfiguration().getEventMeshConnectorPluginType());
+        this.broadcastMqConsumer = new MQConsumerWrapper(
+                eventMeshHTTPServer.getEventMeshHttpConfiguration().getEventMeshConnectorPluginType());
     }
 
     private MessageHandler httpMessageHandler;
@@ -97,157 +97,153 @@ public class EventMeshConsumer {
         Properties keyValue = new Properties();
         keyValue.put(IS_BROADCAST, "false");
         keyValue.put(CONSUMER_GROUP, consumerGroupConf.getConsumerGroup());
-        keyValue.put(EVENT_MESH_IDC, eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshIDC);
+        keyValue.put(EVENT_MESH_IDC, eventMeshHTTPServer.getEventMeshHttpConfiguration().getEventMeshIDC());
         keyValue.put(INSTANCE_NAME, EventMeshUtil.buildMeshClientID(consumerGroupConf.getConsumerGroup(),
-            eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshCluster));
+                eventMeshHTTPServer.getEventMeshHttpConfiguration().getEventMeshCluster()));
         persistentMqConsumer.init(keyValue);
 
-        EventListener clusterEventListener = new EventListener() {
-            @Override
-            public void consume(CloudEvent event, AsyncConsumeContext context) {
-                String protocolVersion =
+        EventListener clusterEventListener = (event, context) -> {
+            String protocolVersion =
                     Objects.requireNonNull(event.getSpecVersion()).toString();
 
-                Span span = TraceUtils.prepareServerSpan(
+            Span span = TraceUtils.prepareServerSpan(
                     EventMeshUtil.getCloudEventExtensionMap(protocolVersion, event),
                     EventMeshTraceConstants.TRACE_DOWNSTREAM_EVENTMESH_SERVER_SPAN, false);
-                try {
-                    String topic = event.getSubject();
-                    String bizSeqNo = event.getExtension(ProtocolKey.ClientInstanceKey.BIZSEQNO).toString();
-                    String uniqueId = event.getExtension(ProtocolKey.ClientInstanceKey.UNIQUEID).toString();
+            try {
+                String topic = event.getSubject();
+                String bizSeqNo = Objects.requireNonNull(event.getExtension(ProtocolKey.ClientInstanceKey.BIZSEQNO)).toString();
+                String uniqueId = Objects.requireNonNull(event.getExtension(ProtocolKey.ClientInstanceKey.UNIQUEID)).toString();
 
-                    event = CloudEventBuilder.from(event)
+                event = CloudEventBuilder.from(event)
                         .withExtension(EventMeshConstants.REQ_MQ2EVENTMESH_TIMESTAMP, String.valueOf(System.currentTimeMillis()))
                         .withExtension(EventMeshConstants.REQ_RECEIVE_EVENTMESH_IP,
-                            eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshServerIp)
+                                eventMeshHTTPServer.getEventMeshHttpConfiguration().getEventMeshServerIp())
                         .build();
-                    if (messageLogger.isDebugEnabled()) {
-                        messageLogger.debug("message|mq2eventMesh|topic={}|event={}", topic, event);
-                    } else {
-                        messageLogger.info("message|mq2eventMesh|topic={}|bizSeqNo={}|uniqueId={}", topic, bizSeqNo, uniqueId);
-                    }
+                if (messageLogger.isDebugEnabled()) {
+                    messageLogger.debug("message|mq2eventMesh|topic={}|event={}", topic, event);
+                } else {
+                    messageLogger.info("message|mq2eventMesh|topic={}|bizSeqNo={}|uniqueId={}", topic, bizSeqNo, uniqueId);
+                }
 
-                    ConsumerGroupTopicConf currentTopicConfig = MapUtils.getObject(consumerGroupConf.getConsumerGroupTopicConf(),
+                ConsumerGroupTopicConf currentTopicConfig = MapUtils.getObject(consumerGroupConf.getConsumerGroupTopicConf(),
                         topic, null);
-                    EventMeshAsyncConsumeContext eventMeshAsyncConsumeContext = (EventMeshAsyncConsumeContext) context;
+                EventMeshAsyncConsumeContext eventMeshAsyncConsumeContext = (EventMeshAsyncConsumeContext) context;
 
-                    if (currentTopicConfig == null) {
-                        logger.error("no topicConfig found, consumerGroup:{} topic:{}", consumerGroupConf.getConsumerGroup(), topic);
-                        try {
-                            sendMessageBack(event, uniqueId, bizSeqNo);
-                            eventMeshAsyncConsumeContext.commit(EventMeshAction.CommitMessage);
-                            return;
-                        } catch (Exception ex) {
-                            //ignore
-                        }
+                if (currentTopicConfig == null) {
+                    logger.error("no topicConfig found, consumerGroup:{} topic:{}",
+                            consumerGroupConf.getConsumerGroup(), topic);
+                    try {
+                        sendMessageBack(event, uniqueId, bizSeqNo);
+                        eventMeshAsyncConsumeContext.commit(EventMeshAction.CommitMessage);
+                        return;
+                    } catch (Exception ex) {
+                        //ignore
                     }
+                }
 
-                    SubscriptionItem subscriptionItem = consumerGroupConf.getConsumerGroupTopicConf().get(topic).getSubscriptionItem();
-                    HandleMsgContext handleMsgContext = new HandleMsgContext(EventMeshUtil.buildPushMsgSeqNo(),
-                        consumerGroupConf.getConsumerGroup(), EventMeshConsumer.this,
+                SubscriptionItem subscriptionItem =
+                        consumerGroupConf.getConsumerGroupTopicConf().get(topic).getSubscriptionItem();
+                HandleMsgContext handleMsgContext = new HandleMsgContext(
+                        EventMeshUtil.buildPushMsgSeqNo(),
+                        consumerGroupConf.getConsumerGroup(),
+                        EventMeshConsumer.this,
                         topic, event, subscriptionItem, eventMeshAsyncConsumeContext.getAbstractContext(),
                         consumerGroupConf, eventMeshHTTPServer, bizSeqNo, uniqueId, currentTopicConfig);
 
-                    if (httpMessageHandler.handle(handleMsgContext)) {
-                        eventMeshAsyncConsumeContext.commit(EventMeshAction.ManualAck);
-                    } else {
-                        try {
-                            sendMessageBack(event, uniqueId, bizSeqNo);
-                        } catch (Exception e) {
-                            //ignore
-                        }
-                        eventMeshAsyncConsumeContext.commit(EventMeshAction.CommitMessage);
+                if (httpMessageHandler.handle(handleMsgContext)) {
+                    eventMeshAsyncConsumeContext.commit(EventMeshAction.ManualAck);
+                } else {
+                    try {
+                        sendMessageBack(event, uniqueId, bizSeqNo);
+                    } catch (Exception e) {
+                        //ignore
                     }
-                } finally {
-                    TraceUtils.finishSpan(span, event);
+                    eventMeshAsyncConsumeContext.commit(EventMeshAction.CommitMessage);
                 }
+            } finally {
+                TraceUtils.finishSpan(span, event);
             }
         };
         persistentMqConsumer.registerEventListener(clusterEventListener);
 
-        //broacast consumer
+        //broadcast consumer
         Properties broadcastKeyValue = new Properties();
         broadcastKeyValue.put(IS_BROADCAST, "true");
         broadcastKeyValue.put(CONSUMER_GROUP, consumerGroupConf.getConsumerGroup());
-        broadcastKeyValue.put(EVENT_MESH_IDC, eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshIDC);
+        broadcastKeyValue.put(EVENT_MESH_IDC, eventMeshHTTPServer.getEventMeshHttpConfiguration().getEventMeshIDC());
         broadcastKeyValue.put(INSTANCE_NAME, EventMeshUtil.buildMeshClientID(consumerGroupConf.getConsumerGroup(),
-            eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshCluster));
+                eventMeshHTTPServer.getEventMeshHttpConfiguration().getEventMeshCluster()));
         broadcastMqConsumer.init(broadcastKeyValue);
 
-        EventListener broadcastEventListener = new EventListener() {
-            @Override
-            public void consume(CloudEvent event, AsyncConsumeContext context) {
+        EventListener broadcastEventListener = (event, context) -> {
 
-                String protocolVersion =
+            String protocolVersion =
                     Objects.requireNonNull(event.getSpecVersion()).toString();
 
-                Span span = TraceUtils.prepareServerSpan(
+            Span span = TraceUtils.prepareServerSpan(
                     EventMeshUtil.getCloudEventExtensionMap(protocolVersion, event),
                     EventMeshTraceConstants.TRACE_DOWNSTREAM_EVENTMESH_SERVER_SPAN, false);
-                try {
+            try {
 
-                    event = CloudEventBuilder.from(event)
+                event = CloudEventBuilder.from(event)
                         .withExtension(EventMeshConstants.REQ_MQ2EVENTMESH_TIMESTAMP,
-                            String.valueOf(System.currentTimeMillis()))
+                                String.valueOf(System.currentTimeMillis()))
                         .withExtension(EventMeshConstants.REQ_RECEIVE_EVENTMESH_IP,
-                            eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshServerIp)
+                                eventMeshHTTPServer.getEventMeshHttpConfiguration().getEventMeshServerIp())
                         .build();
 
-                    String topic = event.getSubject();
-                    String bizSeqNo = event.getExtension(ProtocolKey.ClientInstanceKey.BIZSEQNO) == null ? "" :
-                        event.getExtension(ProtocolKey.ClientInstanceKey.BIZSEQNO).toString();
-                    String uniqueId = event.getExtension(ProtocolKey.ClientInstanceKey.UNIQUEID) == null ? "" :
-                        event.getExtension(ProtocolKey.ClientInstanceKey.UNIQUEID).toString();
+                String topic = event.getSubject();
+                String bizSeqNo = getEventExtension(event, ProtocolKey.ClientInstanceKey.BIZSEQNO, "");
+                String uniqueId = getEventExtension(event, ProtocolKey.ClientInstanceKey.UNIQUEID, "");
 
-                    if (messageLogger.isDebugEnabled()) {
-                        messageLogger.debug("message|mq2eventMesh|topic={}|msg={}", topic, event);
-                    } else {
-                        messageLogger.info("message|mq2eventMesh|topic={}|bizSeqNo={}|uniqueId={}",
+                if (messageLogger.isDebugEnabled()) {
+                    messageLogger.debug("message|mq2eventMesh|topic={}|msg={}", topic, event);
+                } else {
+                    messageLogger.info("message|mq2eventMesh|topic={}|bizSeqNo={}|uniqueId={}",
                             topic, bizSeqNo,
                             uniqueId);
-                    }
+                }
 
-                    ConsumerGroupTopicConf currentTopicConfig = MapUtils.getObject(
+                ConsumerGroupTopicConf currentTopicConfig = MapUtils.getObject(
                         consumerGroupConf.getConsumerGroupTopicConf(), topic, null);
-                    EventMeshAsyncConsumeContext eventMeshAsyncConsumeContext =
+                EventMeshAsyncConsumeContext eventMeshAsyncConsumeContext =
                         (EventMeshAsyncConsumeContext) context;
 
-                    if (currentTopicConfig == null) {
-                        logger.error("no topicConfig found, consumerGroup:{} topic:{}",
+                if (currentTopicConfig == null) {
+                    logger.error("no topicConfig found, consumerGroup:{} topic:{}",
                             consumerGroupConf.getConsumerGroup(), topic);
-                        try {
-                            sendMessageBack(event, uniqueId, bizSeqNo);
-                            eventMeshAsyncConsumeContext.commit(EventMeshAction.CommitMessage);
-                            return;
-                        } catch (Exception ex) {
-                            //ignore
-                        }
-                    }
-
-                    SubscriptionItem subscriptionItem =
-                        consumerGroupConf.getConsumerGroupTopicConf().get(topic)
-                            .getSubscriptionItem();
-                    HandleMsgContext handleMsgContext =
-                        new HandleMsgContext(EventMeshUtil.buildPushMsgSeqNo(),
-                            consumerGroupConf.getConsumerGroup(), EventMeshConsumer.this,
-                            topic, event, subscriptionItem,
-                            eventMeshAsyncConsumeContext.getAbstractContext(),
-                            consumerGroupConf, eventMeshHTTPServer, bizSeqNo, uniqueId,
-                            currentTopicConfig);
-
-                    if (httpMessageHandler.handle(handleMsgContext)) {
-                        eventMeshAsyncConsumeContext.commit(EventMeshAction.ManualAck);
-                    } else {
-                        try {
-                            sendMessageBack(event, uniqueId, bizSeqNo);
-                        } catch (Exception e) {
-                            //ignore
-                        }
+                    try {
+                        sendMessageBack(event, uniqueId, bizSeqNo);
                         eventMeshAsyncConsumeContext.commit(EventMeshAction.CommitMessage);
+                        return;
+                    } catch (Exception ex) {
+                        //ignore
                     }
-                } finally {
-                    TraceUtils.finishSpan(span, event);
                 }
+
+                SubscriptionItem subscriptionItem =
+                        consumerGroupConf.getConsumerGroupTopicConf().get(topic)
+                                .getSubscriptionItem();
+                HandleMsgContext handleMsgContext =
+                        new HandleMsgContext(EventMeshUtil.buildPushMsgSeqNo(),
+                                consumerGroupConf.getConsumerGroup(), EventMeshConsumer.this,
+                                topic, event, subscriptionItem,
+                                eventMeshAsyncConsumeContext.getAbstractContext(),
+                                consumerGroupConf, eventMeshHTTPServer, bizSeqNo, uniqueId,
+                                currentTopicConfig);
+
+                if (httpMessageHandler.handle(handleMsgContext)) {
+                    eventMeshAsyncConsumeContext.commit(EventMeshAction.ManualAck);
+                } else {
+                    try {
+                        sendMessageBack(event, uniqueId, bizSeqNo);
+                    } catch (Exception e) {
+                        //ignore
+                    }
+                    eventMeshAsyncConsumeContext.commit(EventMeshAction.CommitMessage);
+                }
+            } finally {
+                TraceUtils.finishSpan(span, event);
             }
         };
         broadcastMqConsumer.registerEventListener(broadcastEventListener);
@@ -257,6 +253,11 @@ public class EventMeshConsumer {
         logger.info("EventMeshConsumer [{}] inited.............", consumerGroupConf.getConsumerGroup());
     }
 
+    private String getEventExtension(CloudEvent event, String protocolKey, String defaultValue) {
+        Object extension = event.getExtension(protocolKey);
+        return Objects.isNull(extension) ? defaultValue : extension.toString();
+    }
+
     public synchronized void start() throws Exception {
         persistentMqConsumer.start();
         started4Persistent.compareAndSet(false, true);
@@ -311,16 +312,16 @@ public class EventMeshConsumer {
     public void sendMessageBack(final CloudEvent event, final String uniqueId, String bizSeqNo) throws Exception {
 
         EventMeshProducer sendMessageBack
-            = eventMeshHTTPServer.getProducerManager().getEventMeshProducer(consumerGroupConf.getConsumerGroup());
+                = eventMeshHTTPServer.getProducerManager().getEventMeshProducer(consumerGroupConf.getConsumerGroup());
 
         if (sendMessageBack == null) {
             logger.warn("consumer:{} consume fail, sendMessageBack, bizSeqNo:{}, uniqueId:{}",
-                consumerGroupConf.getConsumerGroup(), bizSeqNo, uniqueId);
+                    consumerGroupConf.getConsumerGroup(), bizSeqNo, uniqueId);
             return;
         }
 
         final SendMessageContext sendMessageBackContext = new SendMessageContext(bizSeqNo, event, sendMessageBack,
-            eventMeshHTTPServer);
+                eventMeshHTTPServer);
 
         sendMessageBack.send(sendMessageBackContext, new SendCallback() {
             @Override
@@ -330,7 +331,7 @@ public class EventMeshConsumer {
             @Override
             public void onException(OnExceptionContext context) {
                 logger.warn("consumer:{} consume fail, sendMessageBack, bizSeqno:{}, uniqueId:{}",
-                    consumerGroupConf.getConsumerGroup(), bizSeqNo, uniqueId);
+                        consumerGroupConf.getConsumerGroup(), bizSeqNo, uniqueId);
             }
         });
     }
