@@ -73,11 +73,12 @@ import com.google.common.collect.Sets;
 
 public class AsyncHTTPPushRequest extends AbstractHTTPPushRequest {
 
-    public Logger messageLogger = LoggerFactory.getLogger("message");
+    public static final Logger MESSAGE_LOGGER = LoggerFactory.getLogger("message");
 
-    public Logger cmdLogger = LoggerFactory.getLogger("cmd");
+    public static final Logger CMD_LOGGER = LoggerFactory.getLogger("cmd");
+
+    public static final Logger LOGGER = LoggerFactory.getLogger("AsyncHTTPPushRequest");
 
-    public Logger logger = LoggerFactory.getLogger(this.getClass());
     public String currPushUrl;
     private Map<String, Set<AbstractHTTPPushRequest>> waitingRequests;
 
@@ -99,24 +100,23 @@ public class AsyncHTTPPushRequest extends AbstractHTTPPushRequest {
         HttpPost builder = new HttpPost(currPushUrl);
 
         String requestCode = "";
-
-        if (SubscriptionType.SYNC.equals(handleMsgContext.getSubscriptionItem().getType())) {
+        if (SubscriptionType.SYNC == handleMsgContext.getSubscriptionItem().getType()) {
             requestCode = String.valueOf(RequestCode.HTTP_PUSH_CLIENT_SYNC.getRequestCode());
         } else {
             requestCode = String.valueOf(RequestCode.HTTP_PUSH_CLIENT_ASYNC.getRequestCode());
         }
-
+        String localAddress = IPUtils.getLocalAddress();
         builder.addHeader(ProtocolKey.REQUEST_CODE, requestCode);
         builder.addHeader(ProtocolKey.LANGUAGE, Constants.LANGUAGE_JAVA);
         builder.addHeader(ProtocolKey.VERSION, ProtocolVersion.V1.getVersion());
         builder.addHeader(ProtocolKey.EventMeshInstanceKey.EVENTMESHCLUSTER,
             handleMsgContext.getEventMeshHTTPServer()
-                .getEventMeshHttpConfiguration().eventMeshCluster);
-        builder.addHeader(ProtocolKey.EventMeshInstanceKey.EVENTMESHIP, IPUtils.getLocalAddress());
+                .getEventMeshHttpConfiguration().getEventMeshCluster());
+        builder.addHeader(ProtocolKey.EventMeshInstanceKey.EVENTMESHIP, localAddress);
         builder.addHeader(ProtocolKey.EventMeshInstanceKey.EVENTMESHENV,
-            handleMsgContext.getEventMeshHTTPServer().getEventMeshHttpConfiguration().eventMeshEnv);
+            handleMsgContext.getEventMeshHTTPServer().getEventMeshHttpConfiguration().getEventMeshEnv());
         builder.addHeader(ProtocolKey.EventMeshInstanceKey.EVENTMESHIDC,
-            handleMsgContext.getEventMeshHTTPServer().getEventMeshHttpConfiguration().eventMeshIDC);
+            handleMsgContext.getEventMeshHTTPServer().getEventMeshHttpConfiguration().getEventMeshIDC());
 
         CloudEvent event = CloudEventBuilder.from(handleMsgContext.getEvent())
             .withExtension(EventMeshConstants.REQ_EVENTMESH2C_TIMESTAMP,
@@ -149,7 +149,7 @@ public class AsyncHTTPPushRequest extends AbstractHTTPPushRequest {
             }
 
         } catch (Exception ex) {
-            logger.error("Failed to convert EventMeshMessage from CloudEvent", ex);
+            LOGGER.error("Failed to convert EventMeshMessage from CloudEvent", ex);
             return;
         }
 
@@ -185,17 +185,21 @@ public class AsyncHTTPPushRequest extends AbstractHTTPPushRequest {
         String urlAuthType = handleMsgContext.getConsumerGroupConfig().getConsumerGroupTopicConf()
             .get(handleMsgContext.getTopic()).getHttpAuthTypeMap().get(currPushUrl);
 
-        WebhookUtil.setWebhookHeaders(builder, httpEntity.getContentType().getValue(), eventMeshHttpConfiguration.eventMeshWebhookOrigin,
+        WebhookUtil.setWebhookHeaders(builder, httpEntity.getContentType().getValue(),
+            eventMeshHttpConfiguration.getEventMeshWebhookOrigin(),
             urlAuthType);
 
-        eventMeshHTTPServer.metrics.getSummaryMetrics().recordPushMsg();
+
+        eventMeshHTTPServer.getMetrics().getSummaryMetrics().recordPushMsg();
 
         this.lastPushTime = System.currentTimeMillis();
 
         addToWaitingMap(this);
 
-        cmdLogger.info("cmd={}|eventMesh2client|from={}|to={}", requestCode,
-            IPUtils.getLocalAddress(), currPushUrl);
+        if (CMD_LOGGER.isInfoEnabled()) {
+            CMD_LOGGER.info("cmd={}|eventMesh2client|from={}|to={}", requestCode,
+                localAddress, currPushUrl);
+        }
 
         try {
             eventMeshHTTPServer.httpClientPool.getClient().execute(builder, new ResponseHandler<Object>() {
@@ -203,7 +207,7 @@ public class AsyncHTTPPushRequest extends AbstractHTTPPushRequest {
                 public Object handleResponse(HttpResponse response) {
                     removeWaitingMap(AsyncHTTPPushRequest.this);
                     long cost = System.currentTimeMillis() - lastPushTime;
-                    eventMeshHTTPServer.metrics.getSummaryMetrics().recordHTTPPushTimeCost(cost);
+                    eventMeshHTTPServer.getMetrics().getSummaryMetrics().recordHTTPPushTimeCost(cost);
 
                     if (processResponseStatus(response.getStatusLine().getStatusCode(), response)) {
                         // this is successful response, process response payload
@@ -216,11 +220,13 @@ public class AsyncHTTPPushRequest extends AbstractHTTPPushRequest {
                             return new Object();
                         }
                         ClientRetCode result = processResponseContent(res);
-                        messageLogger.info(
-                            "message|eventMesh2client|{}|url={}|topic={}|bizSeqNo={}"
-                                + "|uniqueId={}|cost={}",
-                            result, currPushUrl, handleMsgContext.getTopic(),
-                            handleMsgContext.getBizSeqNo(), handleMsgContext.getUniqueId(), cost);
+                        if (MESSAGE_LOGGER.isInfoEnabled()) {
+                            MESSAGE_LOGGER.info(
+                                "message|eventMesh2client|{}|url={}|topic={}|bizSeqNo={}"
+                                    + "|uniqueId={}|cost={}",
+                                result, currPushUrl, handleMsgContext.getTopic(),
+                                handleMsgContext.getBizSeqNo(), handleMsgContext.getUniqueId(), cost);
+                        }
                         if (result == ClientRetCode.OK || result == ClientRetCode.REMOTE_OK) {
                             complete();
                             if (isComplete()) {
@@ -243,11 +249,13 @@ public class AsyncHTTPPushRequest extends AbstractHTTPPushRequest {
                             }
                         }
                     } else {
-                        eventMeshHTTPServer.metrics.getSummaryMetrics().recordHttpPushMsgFailed();
-                        messageLogger.info(
-                            "message|eventMesh2client|exception|url={}|topic={}|bizSeqNo={}"
-                                + "|uniqueId={}|cost={}", currPushUrl, handleMsgContext.getTopic(),
-                            handleMsgContext.getBizSeqNo(), handleMsgContext.getUniqueId(), cost);
+                        eventMeshHTTPServer.getMetrics().getSummaryMetrics().recordHttpPushMsgFailed();
+                        if (MESSAGE_LOGGER.isInfoEnabled()) {
+                            MESSAGE_LOGGER.info(
+                                "message|eventMesh2client|exception|url={}|topic={}|bizSeqNo={}"
+                                    + "|uniqueId={}|cost={}", currPushUrl, handleMsgContext.getTopic(),
+                                handleMsgContext.getBizSeqNo(), handleMsgContext.getUniqueId(), cost);
+                        }
 
                         if (isComplete()) {
                             handleMsgContext.finish();
@@ -257,18 +265,20 @@ public class AsyncHTTPPushRequest extends AbstractHTTPPushRequest {
                 }
             });
 
-            if (messageLogger.isDebugEnabled()) {
-                messageLogger.debug("message|eventMesh2client|url={}|topic={}|event={}", currPushUrl,
+            if (MESSAGE_LOGGER.isDebugEnabled()) {
+                MESSAGE_LOGGER.debug("message|eventMesh2client|url={}|topic={}|event={}", currPushUrl,
                     handleMsgContext.getTopic(),
                     handleMsgContext.getEvent());
             } else {
-                messageLogger
-                    .info("message|eventMesh2client|url={}|topic={}|bizSeqNo={}|uniqueId={}",
-                        currPushUrl, handleMsgContext.getTopic(),
-                        handleMsgContext.getBizSeqNo(), handleMsgContext.getUniqueId());
+                if (MESSAGE_LOGGER.isInfoEnabled()) {
+                    MESSAGE_LOGGER
+                        .info("message|eventMesh2client|url={}|topic={}|bizSeqNo={}|uniqueId={}",
+                            currPushUrl, handleMsgContext.getTopic(),
+                            handleMsgContext.getBizSeqNo(), handleMsgContext.getUniqueId());
+                }
             }
         } catch (IOException e) {
-            messageLogger.error("push2client err", e);
+            MESSAGE_LOGGER.error("push2client err", e);
             removeWaitingMap(this);
             delayRetry();
             if (isComplete()) {
@@ -335,16 +345,22 @@ public class AsyncHTTPPushRequest extends AbstractHTTPPushRequest {
 
             return ClientRetCode.FAIL;
         } catch (NumberFormatException e) {
-            messageLogger.warn("url:{}, bizSeqno:{}, uniqueId:{}, httpResponse:{}", currPushUrl,
-                handleMsgContext.getBizSeqNo(), handleMsgContext.getUniqueId(), content);
+            if (MESSAGE_LOGGER.isWarnEnabled()) {
+                MESSAGE_LOGGER.warn("url:{}, bizSeqno:{}, uniqueId:{}, httpResponse:{}", currPushUrl,
+                    handleMsgContext.getBizSeqNo(), handleMsgContext.getUniqueId(), content);
+            }
             return ClientRetCode.FAIL;
         } catch (JsonException e) {
-            messageLogger.warn("url:{}, bizSeqno:{}, uniqueId:{},  httpResponse:{}", currPushUrl,
-                handleMsgContext.getBizSeqNo(), handleMsgContext.getUniqueId(), content);
+            if (MESSAGE_LOGGER.isWarnEnabled()) {
+                MESSAGE_LOGGER.warn("url:{}, bizSeqno:{}, uniqueId:{},  httpResponse:{}", currPushUrl,
+                    handleMsgContext.getBizSeqNo(), handleMsgContext.getUniqueId(), content);
+            }
             return ClientRetCode.FAIL;
         } catch (Throwable t) {
-            messageLogger.warn("url:{}, bizSeqno:{}, uniqueId:{},  httpResponse:{}", currPushUrl,
-                handleMsgContext.getBizSeqNo(), handleMsgContext.getUniqueId(), content);
+            if (MESSAGE_LOGGER.isWarnEnabled()) {
+                MESSAGE_LOGGER.warn("url:{}, bizSeqno:{}, uniqueId:{},  httpResponse:{}", currPushUrl,
+                    handleMsgContext.getBizSeqNo(), handleMsgContext.getUniqueId(), content);
+            }
             return ClientRetCode.FAIL;
         }
     }
