@@ -29,10 +29,15 @@ import org.apache.eventmesh.runtime.util.Utils;
 
 import java.util.Arrays;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import io.netty.channel.ChannelHandlerContext;
 
 public class GoodbyeTask extends AbstractTask {
 
+    private static final Logger LOGGER = LoggerFactory.getLogger(GoodbyeTask.class);
+
     public GoodbyeTask(Package pkg, ChannelHandlerContext ctx, long startTime, EventMeshTCPServer eventMeshTCPServer) {
         super(pkg, ctx, startTime, eventMeshTCPServer);
     }
@@ -43,16 +48,16 @@ public class GoodbyeTask extends AbstractTask {
         Package msg = new Package();
         try {
             if (pkg.getHeader().getCmd() == Command.SERVER_GOODBYE_RESPONSE) {
-                logger.info("client|address={}| has reject ", session.getContext().channel().remoteAddress());
+                LOGGER.info("client|address={}| has reject ", session.getContext().channel().remoteAddress());
             } else {
                 msg.setHeader(
                         new Header(CLIENT_GOODBYE_RESPONSE, OPStatus.SUCCESS.getCode(), OPStatus.SUCCESS.getDesc(),
                                 pkg.getHeader().getSeq()));
             }
         } catch (Exception e) {
-            logger.error("GoodbyeTask failed|user={}|errMsg={}", session.getClient(), e);
-            msg.setHeader(new Header(CLIENT_GOODBYE_RESPONSE, OPStatus.FAIL.getCode(), Arrays.toString(e.getStackTrace()), pkg
-                    .getHeader().getSeq()));
+            LOGGER.error("GoodbyeTask failed|user={}|errMsg={}", session.getClient(), e);
+            msg.setHeader(new Header(CLIENT_GOODBYE_RESPONSE, OPStatus.FAIL.getCode(), Arrays.toString(e.getStackTrace()),
+                    pkg.getHeader().getSeq()));
         } finally {
             this.eventMeshTCPServer.getScheduler().submit(new Runnable() {
                 @Override
