@@ -17,10 +17,11 @@
 
 package org.apache.eventmesh.runtime.util;
 
+import java.io.Serializable;
 import java.util.Comparator;
 import java.util.Map;
 
-public class ValueComparator implements Comparator<Map.Entry<String, Integer>> {
+public class ValueComparator implements Comparator<Map.Entry<String, Integer>>, Serializable {
     @Override
     public int compare(Map.Entry<String, Integer> x, Map.Entry<String, Integer> y) {
         if (x.getValue().intValue() != y.getValue().intValue()) {
