@@ -28,6 +28,7 @@ import static org.mockito.Mockito.mockConstruction;
 import static org.mockito.Mockito.mockStatic;
 import static org.mockito.Mockito.when;
 
+import org.apache.eventmesh.runtime.admin.controller.HttpHandlerManager;
 import org.apache.eventmesh.runtime.boot.EventMeshTCPServer;
 import org.apache.eventmesh.runtime.configuration.EventMeshTCPConfiguration;
 import org.apache.eventmesh.runtime.core.protocol.tcp.client.recommend.EventMeshRecommendImpl;
@@ -38,6 +39,7 @@ import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.net.URI;
+import java.nio.charset.StandardCharsets;
 
 import org.junit.Assert;
 import org.junit.Test;
@@ -61,20 +63,25 @@ public class QueryRecommendEventMeshHandlerTest {
         OutputStream outputStream = new ByteArrayOutputStream();
         HttpExchange httpExchange = mock(HttpExchange.class);
         when(httpExchange.getRequestURI()).thenReturn(uri);
-        QueryRecommendEventMeshHandler handler = new QueryRecommendEventMeshHandler(eventMeshTCPServer);
+        HttpHandlerManager httpHandlerManager = new HttpHandlerManager();
+        QueryRecommendEventMeshHandler handler = new QueryRecommendEventMeshHandler(eventMeshTCPServer, httpHandlerManager);
+
+        String returnValue = "result";
 
         // case 1: normal case
-        tcpConfiguration.eventMeshServerRegistryEnable = true;
+        tcpConfiguration.setEventMeshServerRegistryEnable(true);
+        outputStream.write("result".getBytes(StandardCharsets.UTF_8));
         when(httpExchange.getResponseBody()).thenReturn(outputStream);
         try (MockedConstruction<EventMeshRecommendImpl> ignored = mockConstruction(EventMeshRecommendImpl.class,
-            (mock, context) -> when(mock.calculateRecommendEventMesh(anyString(), anyString())).thenReturn("result"))) {
+            (mock, context) -> when(mock.calculateRecommendEventMesh(anyString(), anyString())).thenReturn(returnValue))) {
             handler.handle(httpExchange);
             String response = outputStream.toString();
-            Assert.assertEquals("result", response);
+            Assert.assertEquals(returnValue, response);
         }
 
         // case 2: params illegal
         outputStream = new ByteArrayOutputStream();
+        outputStream.write("params illegal!".getBytes(StandardCharsets.UTF_8));
         when(httpExchange.getResponseBody()).thenReturn(outputStream);
         try (MockedStatic<StringUtils> dummyStatic = mockStatic(StringUtils.class)) {
             dummyStatic.when(() -> StringUtils.isBlank(any())).thenReturn(true);
@@ -84,15 +91,15 @@ public class QueryRecommendEventMeshHandlerTest {
         }
 
         // case 3: registry disable
-        tcpConfiguration.eventMeshServerRegistryEnable = false;
+        tcpConfiguration.setEventMeshServerRegistryEnable(false);
         outputStream = mock(ByteArrayOutputStream.class);
         doThrow(new IOException()).when(outputStream).close();
         when(httpExchange.getResponseBody()).thenReturn(outputStream);
         try (MockedConstruction<EventMeshRecommendImpl> ignored = mockConstruction(EventMeshRecommendImpl.class,
-            (mock, context) -> when(mock.calculateRecommendEventMesh(anyString(), anyString())).thenReturn("result"))) {
+            (mock, context) -> when(mock.calculateRecommendEventMesh(anyString(), anyString())).thenReturn(returnValue))) {
             handler.handle(httpExchange);
             String response = outputStream.toString();
-            Assert.assertNotEquals("result", response);
+            Assert.assertNotEquals(returnValue, response);
         }
     }
 }
\ No newline at end of file
