@@ -174,7 +174,7 @@ func (e *eventMeshGRPCClient) setupContext(ctx context.Context) context.Context
 
 // Close meshclient and free all resources
 func (e *eventMeshGRPCClient) Close() error {
-	log.Infof("close grpc client")
+	log.Infof("begin close grpc client")
 	if e.cancel != nil {
 		e.cancel()
 	}
@@ -190,8 +190,11 @@ func (e *eventMeshGRPCClient) Close() error {
 		}
 		e.eventMeshConsumer = nil
 	}
-	if err := e.grpcConn.Close(); err != nil {
-		log.Warnf("err in close conn with err:%v", err)
+
+	if e.grpcConn != nil {
+		if err := e.grpcConn.Close(); err != nil {
+			log.Warnf("err in close conn with err:%v", err)
+		}
 	}
 
 	log.Infof("success close grpc client")
