@@ -32,8 +32,8 @@ import java.util.concurrent.ScheduledThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
 
-import com.google.common.base.Preconditions;
-import com.google.common.util.concurrent.ThreadFactoryBuilder;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import io.netty.bootstrap.Bootstrap;
 import io.netty.buffer.PooledByteBufAllocator;
@@ -50,30 +50,33 @@ import io.netty.channel.SimpleChannelInboundHandler;
 import io.netty.channel.nio.NioEventLoopGroup;
 import io.netty.channel.socket.SocketChannel;
 import io.netty.channel.socket.nio.NioSocketChannel;
-import lombok.extern.slf4j.Slf4j;
 
-@Slf4j
+import com.google.common.base.Preconditions;
+import com.google.common.util.concurrent.ThreadFactoryBuilder;
+
 public abstract class TcpClient implements Closeable {
 
-    public final int clientNo = (new Random()).nextInt(1000);
+    private static final Logger LOGGER = LoggerFactory.getLogger(TcpClient.class);
 
-    protected final ConcurrentHashMap<Object, RequestContext> contexts = new ConcurrentHashMap<>();
+    protected static final transient int CLIENTNO = (new Random()).nextInt(1000);
 
-    protected final String    host;
-    protected final int       port;
-    protected final UserAgent userAgent;
+    protected final transient ConcurrentHashMap<Object, RequestContext> contexts = new ConcurrentHashMap<>();
 
-    private final Bootstrap bootstrap = new Bootstrap();
+    protected final transient String host;
+    protected final transient int port;
+    protected final transient UserAgent userAgent;
 
-    private final EventLoopGroup workers = new NioEventLoopGroup();
+    private final transient Bootstrap bootstrap = new Bootstrap();
 
-    private Channel channel;
+    private final transient EventLoopGroup workers = new NioEventLoopGroup();
 
-    private ScheduledFuture<?> heartTask;
+    private transient Channel channel;
+
+    private transient ScheduledFuture<?> heartTask;
 
     protected static final ScheduledThreadPoolExecutor scheduler = new ScheduledThreadPoolExecutor(
-        Runtime.getRuntime().availableProcessors(),
-        new ThreadFactoryBuilder().setNameFormat("TCPClientScheduler").setDaemon(true).build());
+            Runtime.getRuntime().availableProcessors(),
+            new ThreadFactoryBuilder().setNameFormat("TCPClientScheduler").setDaemon(true).build());
 
     public TcpClient(EventMeshTCPClientConfig eventMeshTcpClientConfig) {
         Preconditions.checkNotNull(eventMeshTcpClientConfig, "EventMeshTcpClientConfig cannot be null");
@@ -88,24 +91,25 @@ public abstract class TcpClient implements Closeable {
         bootstrap.group(workers);
         bootstrap.channel(NioSocketChannel.class);
         bootstrap.option(ChannelOption.CONNECT_TIMEOUT_MILLIS, 1_000)
-            .option(ChannelOption.SO_KEEPALIVE, true)
-            .option(ChannelOption.SO_SNDBUF, 64 * 1024)
-            .option(ChannelOption.SO_RCVBUF, 64 * 1024)
-            .option(ChannelOption.RCVBUF_ALLOCATOR, new AdaptiveRecvByteBufAllocator(1024, 8192, 65536))
-            .option(ChannelOption.ALLOCATOR, PooledByteBufAllocator.DEFAULT);
+                .option(ChannelOption.SO_KEEPALIVE, true)
+                .option(ChannelOption.SO_SNDBUF, 64 * 1024)
+                .option(ChannelOption.SO_RCVBUF, 64 * 1024)
+                .option(ChannelOption.RCVBUF_ALLOCATOR, new AdaptiveRecvByteBufAllocator(1024, 8192, 65536))
+                .option(ChannelOption.ALLOCATOR, PooledByteBufAllocator.DEFAULT);
         bootstrap.handler(new ChannelInitializer<SocketChannel>() {
             public void initChannel(SocketChannel ch) {
                 ch.pipeline().addLast(new Codec.Encoder(), new Codec.Decoder())
-                    .addLast(handler, newExceptionHandler());
+                        .addLast(handler, newExceptionHandler());
             }
         });
 
         ChannelFuture f = bootstrap.connect(host, port).sync();
         InetSocketAddress localAddress = (InetSocketAddress) f.channel().localAddress();
         channel = f.channel();
-        log
-            .info("connected|local={}:{}|server={}", localAddress.getAddress().getHostAddress(), localAddress.getPort(),
-                host + ":" + port);
+        if (LOGGER.isInfoEnabled()) {
+            LOGGER.info("connected|local={}:{}|server={}", localAddress.getAddress().getHostAddress(),
+                    localAddress.getPort(), host + ":" + port);
+        }
     }
 
     @Override
@@ -119,7 +123,10 @@ public abstract class TcpClient implements Closeable {
             goodbye();
         } catch (Exception e) {
             Thread.currentThread().interrupt();
-            log.warn("close tcp client failed.|remote address={}", channel.remoteAddress(), e);
+
+            if (LOGGER.isWarnEnabled()) {
+                LOGGER.warn("close tcp client failed.|remote address={}", channel.remoteAddress(), e);
+            }
         }
     }
 
@@ -133,8 +140,10 @@ public abstract class TcpClient implements Closeable {
                         }
                         Package msg = MessageUtils.heartBeat();
                         io(msg, EventMeshCommon.DEFAULT_TIME_OUT_MILLS);
-                        log.debug("heart beat start {}", msg);
-                    } catch (Exception ignore) {
+                        if (LOGGER.isDebugEnabled()) {
+                            LOGGER.debug("heart beat start {}", msg);
+                        }
+                    } catch (Exception e) {
                         // ignore
                     }
                 }, EventMeshCommon.HEARTBEAT, EventMeshCommon.HEARTBEAT, TimeUnit.MILLISECONDS);
@@ -155,7 +164,9 @@ public abstract class TcpClient implements Closeable {
         if (channel.isWritable()) {
             channel.writeAndFlush(msg).addListener((ChannelFutureListener) future -> {
                 if (!future.isSuccess()) {
-                    log.warn("send msg failed", future.cause());
+                    if (LOGGER.isWarnEnabled()) {
+                        LOGGER.warn("send msg failed", future.cause());
+                    }
                 }
             });
         } else {
@@ -164,13 +175,15 @@ public abstract class TcpClient implements Closeable {
     }
 
     protected Package io(Package msg, long timeout) throws Exception {
-        Object key = RequestContext._key(msg);
+        Object key = RequestContext.key(msg);
         CountDownLatch latch = new CountDownLatch(1);
-        RequestContext c = RequestContext._context(key, msg, latch);
+        RequestContext c = RequestContext.context(key, msg, latch);
         if (!contexts.contains(c)) {
             contexts.put(key, c);
         } else {
-            log.info("duplicate key : {}", key);
+            if (LOGGER.isInfoEnabled()) {
+                LOGGER.info("duplicate key : {}", key);
+            }
         }
         send(msg);
         if (!c.getLatch().await(timeout, TimeUnit.MILLISECONDS)) {
@@ -195,8 +208,10 @@ public abstract class TcpClient implements Closeable {
         return new ChannelDuplexHandler() {
             @Override
             public void exceptionCaught(ChannelHandlerContext ctx, Throwable cause) {
-                log
-                    .info("exceptionCaught, close connection.|remote address={}", ctx.channel().remoteAddress(), cause);
+                if (LOGGER.isInfoEnabled()) {
+                    LOGGER.info("exceptionCaught, close connection.|remote address={}",
+                            ctx.channel().remoteAddress(), cause);
+                }
                 ctx.close();
             }
         };
