@@ -69,7 +69,7 @@ class CloudEventTCPSubClient extends TcpClient implements EventMeshTCPSubClient<
             open(new CloudEventTCPSubHandler(contexts));
             hello();
             heartbeat();
-            log.info("SimpleSubClientImpl|{}|started!", clientNo);
+            log.info("SimpleSubClientImpl|{}|started!", CLIENTNO);
         } catch (Exception ex) {
             throw new EventMeshException("Initialize EventMeshMessageTcpSubClient error", ex);
         }
@@ -81,9 +81,11 @@ class CloudEventTCPSubClient extends TcpClient implements EventMeshTCPSubClient<
             super.reconnect();
             hello();
             if (!CollectionUtils.isEmpty(subscriptionItems)) {
-                for (SubscriptionItem item : subscriptionItems) {
-                    Package request = MessageUtils.subscribe(item.getTopic(), item.getMode(), item.getType());
-                    this.io(request, EventMeshCommon.DEFAULT_TIME_OUT_MILLS);
+                synchronized (subscriptionItems) {
+                    for (SubscriptionItem item : subscriptionItems) {
+                        Package request = MessageUtils.subscribe(item.getTopic(), item.getMode(), item.getType());
+                        this.io(request, EventMeshCommon.DEFAULT_TIME_OUT_MILLS);
+                    }
                 }
             }
             listen();
@@ -135,7 +137,7 @@ class CloudEventTCPSubClient extends TcpClient implements EventMeshTCPSubClient<
             goodbye();
             super.close();
         } catch (Exception ex) {
-            ex.printStackTrace();
+            log.error("exception occurred when close", ex);
         }
     }
 
