@@ -19,7 +19,7 @@ package org.apache.eventmesh.webhook.api.utils;
 
 public class StringUtils {
 
-    public static final String getFileName(String path) {
+    public static String getFileName(String path) {
         return path.substring(1).replace('/', '.');
     }
 }
