@@ -17,6 +17,8 @@ package dal
 
 import (
 	"context"
+	"errors"
+	"fmt"
 	"github.com/apache/incubator-eventmesh/eventmesh-workflow-go/internal/util"
 	"time"
 
@@ -30,12 +32,17 @@ import (
 	"gorm.io/gorm"
 )
 
+const maxSize = 100
+
 type WorkflowDAL interface {
-	Select(ctx context.Context, workflowID string) (*model.Workflow, error)
+	Select(ctx context.Context, tx *gorm.DB, workflowID string) (*model.Workflow, error)
+	SelectList(ctx context.Context, param *model.QueryParam) ([]model.Workflow, int, error)
+	Save(ctx context.Context, record *model.Workflow) error
+	Delete(ctx context.Context, workflowID string) error
+	SelectInstances(ctx context.Context, param *model.QueryParam) ([]model.WorkflowInstance, int, error)
 	SelectStartTask(ctx context.Context, condition model.WorkflowTask) (*model.WorkflowTask, error)
 	SelectTransitionTask(ctx context.Context, condition model.WorkflowTaskInstance) (*model.WorkflowTaskInstance, error)
 	SelectTaskInstance(ctx context.Context, condition model.WorkflowTaskInstance) (*model.WorkflowTaskInstance, error)
-	Insert(ctx context.Context, record *model.Workflow) error
 	InsertInstance(ctx context.Context, record *model.WorkflowInstance) error
 	InsertTaskInstance(ctx context.Context, record *model.WorkflowTaskInstance) error
 	UpdateInstance(ctx context.Context, record *model.WorkflowInstance) error
@@ -50,10 +57,10 @@ func NewWorkflowDAL() WorkflowDAL {
 type workflowDALImpl struct {
 }
 
-func (w *workflowDALImpl) Select(ctx context.Context, workflowID string) (*model.Workflow, error) {
-	var condition = model.Workflow{WorkflowID: workflowID}
+func (w *workflowDALImpl) Select(ctx context.Context, tx *gorm.DB, workflowID string) (*model.Workflow, error) {
+	var condition = model.Workflow{WorkflowID: workflowID, Status: constants.NormalStatus}
 	var r model.Workflow
-	if err := workflowDB.WithContext(ctx).Where(&condition).First(&r).Error; err != nil {
+	if err := tx.WithContext(ctx).Where(&condition).First(&r).Error; err != nil {
 		if err == gorm.ErrRecordNotFound {
 			return nil, nil
 		}
@@ -62,6 +69,64 @@ func (w *workflowDALImpl) Select(ctx context.Context, workflowID string) (*model
 	return &r, nil
 }
 
+func (w *workflowDALImpl) SelectList(ctx context.Context, param *model.QueryParam) ([]model.Workflow, int, error) {
+	var res []model.Workflow
+	var condition = model.Workflow{WorkflowID: param.WorkflowID, Status: param.Status}
+	db := workflowDB.WithContext(ctx).Where("1=1")
+	if len(condition.WorkflowID) > 0 {
+		// Suitable for small amount of data
+		// when the amount of data is too large, you need to use search engines for optimization
+		db = db.Where("workflow_id LIKE ?", fmt.Sprintf("%%%s%%", condition.WorkflowID))
+	}
+	if condition.Status == 0 {
+		condition.Status = constants.NormalStatus
+	}
+	db = db.Where("status = ?", condition.Status)
+	if param.Size > maxSize {
+		param.Size = maxSize
+	}
+	if param.Page == 0 {
+		param.Page = 1
+	}
+	var count int64
+	db = db.Limit(param.Size).Offset(param.Size * (param.Page - 1)).Order("update_time DESC")
+	if err := db.Find(&res).Limit(-1).Offset(-1).Count(&count).Error; err != nil {
+		if err == gorm.ErrRecordNotFound {
+			return nil, 0, nil
+		}
+		return nil, 0, err
+	}
+	if count == 0 {
+		return res, int(count), nil
+	}
+	if err := w.fillInstanceCount(res); err != nil {
+		return res, int(count), err
+	}
+	return res, int(count), nil
+}
+
+func (w *workflowDALImpl) SelectInstances(ctx context.Context, param *model.QueryParam) ([]model.WorkflowInstance,
+	int, error) {
+	var r []model.WorkflowInstance
+	db := workflowDB.WithContext(ctx).Where("workflow_status != ?", constants.InvalidStatus).
+		Where("workflow_id = ?", param.WorkflowID)
+	if param.Size > maxSize {
+		param.Size = maxSize
+	}
+	if param.Page == 0 {
+		param.Page = 1
+	}
+	var count int64
+	db = db.Limit(param.Size).Offset(param.Size * (param.Page - 1)).Order("update_time DESC")
+	if err := db.Find(&r).Limit(-1).Offset(-1).Count(&count).Error; err != nil {
+		if err == gorm.ErrRecordNotFound {
+			return nil, 0, nil
+		}
+		return nil, 0, err
+	}
+	return r, int(count), nil
+}
+
 func (w *workflowDALImpl) SelectStartTask(ctx context.Context, condition model.WorkflowTask) (*model.WorkflowTask,
 	error) {
 	var c = model.WorkflowTaskRelation{FromTaskID: constants.TaskStartID, WorkflowID: condition.WorkflowID,
@@ -99,11 +164,11 @@ func (w *workflowDALImpl) SelectTaskInstance(ctx context.Context, condition mode
 		}
 		return nil, err
 	}
-	var handlers []func() error
 	var err error
 	var tasks []*model.WorkflowTask
 	var childTasks []*model.WorkflowTaskRelation
 	var taskActions []*model.WorkflowTaskAction
+	var handlers []func() error
 	handlers = append(handlers, func() error {
 		tasks, err = w.selectTask(context.Background(), r.WorkflowID, []string{r.TaskID})
 		return err
@@ -125,43 +190,20 @@ func (w *workflowDALImpl) SelectTaskInstance(ctx context.Context, condition mode
 	return w.completeTaskInstance(r, tasks, childTasks, taskActions)
 }
 
-func (w *workflowDALImpl) Insert(ctx context.Context, record *model.Workflow) error {
+// Delete delete workflow and relate info
+func (w *workflowDALImpl) Delete(ctx context.Context, workflowID string) error {
+	return w.delete(workflowDB, workflowID)
+}
+
+func (w *workflowDALImpl) Save(ctx context.Context, record *model.Workflow) error {
 	return workflowDB.WithContext(ctx).Transaction(func(tx *gorm.DB) error {
-		wf, err := swf.Parse(record.Definition)
-		if err != nil {
-			return err
-		}
-		record.WorkflowID = wf.ID
-		record.WorkflowName = wf.Name
-		record.Version = wf.Version
-		record.Status = constants.NormalStatus
-		record.CreateTime = time.Now()
-		record.UpdateTime = time.Now()
-		var handlers []func() error
-		handlers = append(handlers, func() error {
-			return tx.Create(record).Error
-		})
-		tasks := w.buildTask(wf)
-		for _, task := range tasks {
-			task := task
-			handlers = append(handlers, func() error {
-				return tx.Create(task).Error
-			})
-			for _, action := range task.Actions {
-				action := action
-				handlers = append(handlers, func() error {
-					return tx.Create(action).Error
-				})
+		// first delete and insert
+		if len(record.WorkflowID) > 0 {
+			if err := w.delete(tx, record.WorkflowID); err != nil {
+				return err
 			}
 		}
-		taskRelations := w.buildTaskRelation(wf, tasks)
-		for _, relation := range taskRelations {
-			relation := relation
-			handlers = append(handlers, func() error {
-				return tx.Create(relation).Error
-			})
-		}
-		return util.GoAndWait(handlers...)
+		return w.create(ctx, tx, record)
 	})
 }
 
@@ -190,6 +232,84 @@ func (w *workflowDALImpl) UpdateTaskInstance(tx *gorm.DB, record *model.Workflow
 	return tx.Where(&condition).Updates(&record).Error
 }
 
+func (w *workflowDALImpl) delete(tx *gorm.DB, workflowID string) error {
+	var handlers []func() error
+	handlers = append(handlers, func() error {
+		record := model.Workflow{Status: constants.InvalidStatus, UpdateTime: time.Now()}
+		return tx.Where("workflow_id = ?", workflowID).Updates(&record).Error
+	}, func() error {
+		record := model.WorkflowTask{Status: constants.InvalidStatus, UpdateTime: time.Now()}
+		return tx.Where("workflow_id = ?", workflowID).Updates(&record).Error
+	}, func() error {
+		record := model.WorkflowTaskRelation{Status: constants.InvalidStatus,
+			UpdateTime: time.Now()}
+		return tx.Where("workflow_id = ?", workflowID).Updates(&record).Error
+	}, func() error {
+		record := model.WorkflowTaskAction{Status: constants.InvalidStatus,
+			UpdateTime: time.Now()}
+		return tx.Where("workflow_id = ?", workflowID).Updates(&record).Error
+	}, func() error {
+		record := model.WorkflowInstance{WorkflowStatus: constants.InvalidStatus,
+			UpdateTime: time.Now()}
+		return tx.Where("workflow_id = ?", workflowID).Updates(&record).Error
+	}, func() error {
+		record := model.WorkflowTaskInstance{Status: constants.InvalidStatus,
+			UpdateTime: time.Now()}
+		return tx.Where("workflow_id = ?", workflowID).Updates(&record).Error
+	})
+	return util.GoAndWait(handlers...)
+}
+
+func (w *workflowDALImpl) create(ctx context.Context, tx *gorm.DB, record *model.Workflow) error {
+	wf, err := swf.Parse(record.Definition)
+	if err != nil {
+		return err
+	}
+	if wf == nil {
+		return errors.New("workflow text invalid")
+	}
+	r, err := w.Select(ctx, tx, wf.ID)
+	if err != nil {
+		return err
+	}
+	if r != nil {
+		return errors.New("workflow id already exists")
+	}
+	var insertData = model.Workflow{}
+	insertData.WorkflowID = wf.ID
+	insertData.WorkflowName = wf.Name
+	insertData.Version = wf.Version
+	insertData.Definition = record.Definition
+	insertData.Status = constants.NormalStatus
+	insertData.CreateTime = time.Now()
+	insertData.UpdateTime = time.Now()
+	var handlers []func() error
+	handlers = append(handlers, func() error {
+		return tx.Create(insertData).Error
+	})
+	tasks := w.buildTask(wf)
+	for _, task := range tasks {
+		task := task
+		handlers = append(handlers, func() error {
+			return tx.Create(task).Error
+		})
+		for _, action := range task.Actions {
+			action := action
+			handlers = append(handlers, func() error {
+				return tx.Create(action).Error
+			})
+		}
+	}
+	taskRelations := w.buildTaskRelation(wf, tasks)
+	for _, relation := range taskRelations {
+		relation := relation
+		handlers = append(handlers, func() error {
+			return tx.Create(relation).Error
+		})
+	}
+	return util.GoAndWait(handlers...)
+}
+
 func (w *workflowDALImpl) buildTask(workflow *pmodel.Workflow) []*model.WorkflowTask {
 	if workflow == nil || len(workflow.States) == 0 {
 		return nil
@@ -206,11 +326,19 @@ func (w *workflowDALImpl) buildTask(workflow *pmodel.Workflow) []*model.Workflow
 		task.CreateTime = time.Now()
 		task.UpdateTime = time.Now()
 		task.Actions = w.buildTaskAction(task.TaskID, workflow, state)
+		w.fillTaskFilterIfExist(state, &task)
 		tasks = append(tasks, &task)
 	}
 	return tasks
 }
 
+func (w *workflowDALImpl) fillTaskFilterIfExist(workflowState pmodel.State, task *model.WorkflowTask) {
+	filter := workflowState.GetStateDataFilter()
+	if filter != nil {
+		task.TaskInputFilter = filter.Input
+	}
+}
+
 func (w *workflowDALImpl) buildTaskAction(taskID string, workflow *pmodel.Workflow,
 	state pmodel.State) []*model.WorkflowTaskAction {
 	var functions = make(map[string]*pmodel.Function)
@@ -423,3 +551,30 @@ func (w *workflowDALImpl) completeTaskInstance(instance model.WorkflowTaskInstan
 	r.Task.Actions = taskActions
 	return &r, nil
 }
+
+func (w *workflowDALImpl) fillInstanceCount(workflows []model.Workflow) error {
+	var handlers []func() error
+	for idx := range workflows {
+		idx := idx
+		handlers = append(handlers, func() error {
+			var instances []model.WorkflowInstance
+			if err := workflowDB.Where("workflow_id = ?", workflows[idx].WorkflowID).
+				Where("workflow_status != ?", constants.InvalidStatus).Find(&instances).Error; err != nil {
+				return err
+			}
+			if len(instances) == 0 {
+				return nil
+			}
+			workflows[idx].TotalInstances = len(instances)
+			for _, instance := range instances {
+				if instance.WorkflowStatus == constants.TaskInstanceFailStatus {
+					workflows[idx].TotalFailedInstances++
+				} else {
+					workflows[idx].TotalRunningInstances++
+				}
+			}
+			return nil
+		})
+	}
+	return util.GoAndWait(handlers...)
+}
